@@ -5,10 +5,11 @@ from quickbuild.exceptions import (
     QBForbiddenError,
     QBNotFoundError,
     QBProcessingError,
+    QBServerError,
 )
 from quickbuild.helpers import ContentType
 
-__version__ = '0.7.0'
+__version__ = '0.9.0'
 
 __all__ = (
     # adapters
@@ -19,6 +20,7 @@ __all__ = (
     'QBForbiddenError',
     'QBNotFoundError',
     'QBProcessingError',
+    'QBServerError',
     # other
     'ContentType',
 )
