@@ -12,8 +12,11 @@ from quickbuild.endpoints import (
     Configurations,
     Dashboards,
     Groups,
+    Identifiers,
+    Measurements,
     Memberships,
     Requests,
+    Shares,
     System,
     Tokens,
     Users,
@@ -46,8 +49,11 @@ class QuickBuild:
         self.configurations = Configurations(self)
         self.dashboards = Dashboards(self)
         self.groups = Groups(self)
+        self.identifiers = Identifiers(self)
+        self.measurements = Measurements(self)
         self.memberships = Memberships(self)
         self.requests = Requests(self)
+        self.shares = Shares(self)
         self.system = System(self)
         self.tokens = Tokens(self)
         self.users = Users(self)
@@ -100,6 +106,15 @@ class QuickBuild:
 
         return callback(response.body)
 
+    @staticmethod
+    def _validate_retry_argument(retry: dict) -> None:
+        for key in retry:
+            if key not in ('total', 'factor', 'statuses'):
+                raise QBError('Unknown key in retry argument: ' + key)
+
+        if retry.get('total', 0) <= 0:
+            raise QBError('Invalid `total` in retry argument must be > 0')
+
     @staticmethod
     def _validate_for_id(configuration: str) -> None:
         if '</id>' in configuration:
