@@ -4,8 +4,11 @@ from .builds import Builds
 from .configurations import Configurations
 from .dashboards import Dashboards
 from .groups import Groups
+from .identifiers import Identifiers
+from .measurements import Measurements
 from .memberships import Memberships
 from .requests import Requests
+from .shares import Shares
 from .system import System
 from .tokens import Tokens
 from .users import Users
@@ -17,8 +20,11 @@ __all__ = (
     'Configurations',
     'Dashboards',
     'Groups',
+    'Identifiers',
+    'Measurements',
     'Memberships',
     'Requests',
+    'Shares',
     'System',
     'Tokens',
     'Users',
