@@ -1,6 +1,7 @@
 from functools import partial
 from typing import List, Optional, Union
 
+from quickbuild.endpoints.shares import GroupShares
 from quickbuild.helpers import ContentType, response2py
 
 
@@ -9,6 +10,8 @@ class Groups:
     def __init__(self, quickbuild):
         self.quickbuild = quickbuild
 
+        self.shares = GroupShares(quickbuild)
+
     def get(self) -> List[dict]:
         """
         Get all groups in the system.
@@ -48,6 +51,21 @@ class Groups:
             content_type=content_type,
         )
 
+    def get_id_by_name(self, name: str) -> int:
+        """
+        Get group id by name.
+
+        Args:
+            name (str): group name.
+
+        Returns:
+            int: group identifier.
+
+        Raises:
+            QBProcessingError: will be raised if resource is not found.
+        """
+        return self.quickbuild.identifiers.get_group_id_by_name(name)
+
     def update(self, configuration: str) -> int:
         """
         Update a group using XML configuration.
