@@ -44,8 +44,7 @@ BUILD_INFO_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
 """
 
 
-BUILD_STEPS_XML = r"""
-<?xml version="1.0" encoding="UTF-8"?>
+BUILD_STEPS_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
 
 <list>
   <com.pmease.quickbuild.stepsupport.SequentialStep>
@@ -181,6 +180,134 @@ BUILD_SEARCH_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
 </list>
 """
 
+BUILD_FILES_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
+
+<list>
+  <com.pmease.quickbuild.rest.FileInfo>
+    <name>file1.zip</name>
+
+    <!-- size in bytes -->
+    <size>287111</size>
+
+    <!-- number of milliseconds since January 1, 1970, 00:00:00 GMT -->
+    <lastModified>1258091663171</lastModified>
+
+    <directory>false</directory>
+  </com.pmease.quickbuild.rest.FileInfo>
+
+  <com.pmease.quickbuild.rest.FileInfo>
+    <name>dir1</name>
+    <size>0</size>
+    <lastModified>1258091663171</lastModified>
+    <directory>true</directory>
+  </com.pmease.quickbuild.rest.FileInfo>
+</list>
+"""
+
+BUILD_NOTIFICATIONS_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
+
+<list>
+  <com.pmease.quickbuild.model.Build>
+    <id>16</id>
+    <configuration>2</configuration>
+    <version>1.0.15</version>
+    <requester>1</requester>
+
+    <scheduled>false</scheduled>
+    <status>SUCCESSFUL</status>
+    <statusDate>2010-06-09T21:46:11.627+08:00</statusDate>
+    <beginDate>2010-06-09T21:46:11.131+08:00</beginDate>
+    <duration>496</duration>
+    <stepRuntimes>
+
+      <entry>
+        <string>master</string>
+        <com.pmease.quickbuild.stepsupport.StepRuntime>
+          <status>SUCCESSFUL</status>
+          <nodeAddress>matrix:8810</nodeAddress>
+          <duration>424</duration>
+        </com.pmease.quickbuild.stepsupport.StepRuntime>
+
+      </entry>
+      <entry>
+        <string>master&gt;checkout</string>
+        <com.pmease.quickbuild.stepsupport.StepRuntime>
+          <status>SUCCESSFUL</status>
+          <nodeAddress>matrix:8810</nodeAddress>
+          <duration>380</duration>
+
+        </com.pmease.quickbuild.stepsupport.StepRuntime>
+      </entry>
+    </stepRuntimes>
+    <repositoryRuntimes>
+      <entry>
+        <string>svn</string>
+        <com.pmease.quickbuild.repositorysupport.RepositoryRuntime>
+          <revisionDOM>
+
+            <com.pmease.quickbuild.plugin.scm.svn.SvnRevision revision="0.0">
+              <value>101</value>
+            </com.pmease.quickbuild.plugin.scm.svn.SvnRevision>
+          </revisionDOM>
+          <checkout>true</checkout>
+        </com.pmease.quickbuild.repositorysupport.RepositoryRuntime>
+      </entry>
+    </repositoryRuntimes>
+
+    <variableValues/>
+  </com.pmease.quickbuild.model.Build>
+  <com.pmease.quickbuild.model.Build>
+    <id>17</id>
+    <configuration>2</configuration>
+    <version>1.0.16</version>
+    <requester>1</requester>
+
+    <scheduled>false</scheduled>
+    <status>SUCCESSFUL</status>
+    <statusDate>2010-06-09T21:46:13.448+08:00</statusDate>
+    <beginDate>2010-06-09T21:46:12.854+08:00</beginDate>
+    <duration>594</duration>
+    <stepRuntimes>
+
+      <entry>
+        <string>master</string>
+        <com.pmease.quickbuild.stepsupport.StepRuntime>
+          <status>SUCCESSFUL</status>
+          <nodeAddress>matrix:8810</nodeAddress>
+          <duration>535</duration>
+        </com.pmease.quickbuild.stepsupport.StepRuntime>
+
+      </entry>
+      <entry>
+        <string>master&gt;checkout</string>
+        <com.pmease.quickbuild.stepsupport.StepRuntime>
+          <status>SUCCESSFUL</status>
+          <nodeAddress>matrix:8810</nodeAddress>
+          <duration>492</duration>
+
+        </com.pmease.quickbuild.stepsupport.StepRuntime>
+      </entry>
+    </stepRuntimes>
+    <repositoryRuntimes>
+      <entry>
+        <string>svn</string>
+        <com.pmease.quickbuild.repositorysupport.RepositoryRuntime>
+          <revisionDOM>
+
+            <com.pmease.quickbuild.plugin.scm.svn.SvnRevision revision="0.0">
+              <value>101</value>
+            </com.pmease.quickbuild.plugin.scm.svn.SvnRevision>
+          </revisionDOM>
+          <checkout>true</checkout>
+        </com.pmease.quickbuild.repositorysupport.RepositoryRuntime>
+      </entry>
+    </repositoryRuntimes>
+
+    <variableValues/>
+  </com.pmease.quickbuild.model.Build>
+</list>
+"""
+
 
 @responses.activate
 def test_get_info(client):
@@ -326,8 +453,7 @@ def test_get_steps(client):
 
 @responses.activate
 def test_get_repositories(client):
-    BUILD_REPOSITORIES_XML = r"""
-    <?xml version="1.0" encoding="UTF-8"?>
+    BUILD_REPOSITORIES_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
 
     <list/>
     """
@@ -345,8 +471,7 @@ def test_get_repositories(client):
 
 @responses.activate
 def test_get_dependencies(client):
-    RESPONSE_DATA = r"""
-    <?xml version="1.0" encoding="UTF-8"?>
+    RESPONSE_DATA = r"""<?xml version="1.0" encoding="UTF-8"?>
 
     <list/>
     """
@@ -364,8 +489,7 @@ def test_get_dependencies(client):
 
 @responses.activate
 def test_get_dependents(client):
-    RESPONSE_DATA = r"""
-    <?xml version="1.0" encoding="UTF-8"?>
+    RESPONSE_DATA = r"""<?xml version="1.0" encoding="UTF-8"?>
 
     <list/>
     """
@@ -381,6 +505,33 @@ def test_get_dependents(client):
     assert 'list' in response
 
 
+@responses.activate
+def test_get_files(client):
+    responses.add(
+        responses.GET,
+        re.compile(r'.*/rest/files'),
+        content_type='application/xml',
+        body=BUILD_FILES_XML,
+    )
+
+    response = client.builds.get_files(1, 'some_path')
+    assert response[0]['name'] == 'file1.zip'
+    assert response[0]['size'] == 287111
+
+
+@responses.activate
+def test_get_notifications(client):
+    responses.add(
+        responses.GET,
+        re.compile(r'.*/rest/notifications'),
+        content_type='application/xml',
+        body=BUILD_NOTIFICATIONS_XML,
+    )
+
+    response = client.builds.get_notifications(15)
+    assert response[0]['id'] == 16
+
+
 @responses.activate
 def test_search(client):
     responses.add(
